diff --git a/docs/releasenotes/7.0.3.rst b/docs/releasenotes/7.0.3.rst
index 6a3fb7419cae213f1e3fe989f976fdc497753083..d7baf6c27d22d253c9d6549284e3e24dcf2d7f6c 100644
--- a/docs/releasenotes/7.0.3.rst
+++ b/docs/releasenotes/7.0.3.rst
@@ -123,6 +123,9 @@ Diff Viewer
   These are generated on some buggy older versions of GNU Patch and by some
   third-party patch tools.
 
+* Fixed being able to scroll the list of existing comments on a line in the
+  comment dialog.
+
 
 File Attachments
 ----------------
diff --git a/reviewboard/static/rb/js/reviews/views/commentDialogView.ts b/reviewboard/static/rb/js/reviews/views/commentDialogView.ts
index e4db8bb8ffbad69155b5b05e0003ebc654d102e6..eecbc3295197e8557caa7567aec6ead4c26bc63c 100644
--- a/reviewboard/static/rb/js/reviews/views/commentDialogView.ts
+++ b/reviewboard/static/rb/js/reviews/views/commentDialogView.ts
@@ -1042,9 +1042,12 @@ export class CommentDialogView extends BaseView<
         if (textEl === null) {
             /*
              * If the event is happening in the comment dialog but not in the
              * text editor, we can just swallow it right away.
              */
-            evt.preventDefault();
+            if (target.closest('.other-comments > ul') === null) {
+                evt.preventDefault();
+            }
         } else {
             /*
              * If the event is in the text editor, we need to figure out if the
@@ -1042,9 +1042,12 @@ export class CommentDialogView extends BaseView<
             /*
              * If the event is happening in the comment dialog but not in the
-             * text editor, we can just swallow it right away.
+             * text editor or Other Comments area, we can just swallow it
+             * right away.
              */
